@@ -49,35 +49,48 @@ class JiraSession(requests.Session):
             attempt += 1
         return resp
 
-    def link_issues(self, main_issue_key:str, sub_issue_key:str, relationship:str = 'relates to') -> requests.Response:
+    def link_issues(self, in_issue_key:str, out_issue_key:str, link_type:str = 'relates to',
+                    comment: dict = None) -> requests.Response:
         """link two issues together, in and out will relate to jira api route but has no effect on functionality
         
-        main_issue_key {str} -- main issue key
-        sub_issue_key {str} -- sub issue key to link with main
-        relationship {str] -- type of link, default: Relates To
+        in_issue_key {str} -- the issue to link from
+        out_issue_key {str} -- the issue to link to
+        link_type {str] -- type of link, default: Relates To
         comment {dict} [optional] -- comment for linking of issues
         
         return {requests.Response} -- response from issuelink route
         """
-        #attempt to get sub issue
-        resp = self.get_issue(sub_issue_key)
-        if resp.status_code != 200:
-            return resp
-        sub_issue = resp.json()
+        # get link types
+        if not hasattr(self, 'issue_link_types'):
+            resp = self.link_types()
+            if resp.status_code != 200:
+                return resp
 
-        url = f'{self.base_url}/issue/{main_issue_key}/remotelink'
+            self.issue_link_types = resp.json().get('issueLinkTypes', [])
+
+        for ilt in self.issue_link_types:
+            if link_type.lower() == ilt.get('inward', '').lower() \
+                    or link_type.lower() == ilt.get('outward', '').lower():
+                link_type = ilt.get('name', '')
+                break
+
+        url = f'{self.base_url}/issueLink'
         payload = {
-            'relationship': relationship,
-            'object': {
-                'summary': sub_issue.get('fields', {}).get('summary',
-                                                           f'Linking {sub_issue_key!r}to {main_issue_key!r}'),
-                'title': sub_issue_key,
-                'url': sub_issue.get('self', f'{self.base_url}/issue/{sub_issue_key}'),
-                'status': sub_issue.get('fields', {}).get('status', {})
-            }
+            'type': {'name':link_type},
+            'inwardIssue': {'key': in_issue_key},
+            'outwardIssue': {'key': out_issue_key},
+            'comment': comment
         }
         return self._resolver(partial(self.post, url, data=json.dumps(payload)))
 
+    def link_types(self) -> requests.Response:
+        """
+        retrieve the link types for jira issues
+
+        return {requests.Response} -- response from issueLinkType route
+        """
+        return self._resolver(partial(self.get, f'{self.base_url}/issueLinkType'))
+
     def add_attachment(self, issue_key: str, filepath: str) -> requests.Response:
         """
         add an attachment to an issue
@@ -104,10 +117,9 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from post
         """
-        url = f'{self.base_url}/issue'
         if 'fields' not in content:
             content = {'fields': content}
-        return self._resolver(partial(self.post, url, data=json.dumps(content)))
+        return self._resolver(partial(self.post, f'{self.base_url}/issue', data=json.dumps(content)))
 
     def get_issue(self, issue_key: str, fields:list = ['*all'], expand:dict = {}) -> requests.Response:
         """
@@ -119,11 +131,10 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from issue route (GET)
         """
-        url = f'{self.base_url}/issue/{issue_key}'
         params = {'fields':fields}
         if expand:
             params.update({'expand': expand})
-        return self._resolver(partial(self.get, url, params=params))
+        return self._resolver(partial(self.get, f'{self.base_url}/issue/{issue_key}', params=params))
 
     def delete_issue(self, issue_key: str, delete_subtasks:bool=False) -> requests.Response:
         """
@@ -133,9 +144,8 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from delete
         """
-        url = f'{self.base_url}/issue/{issue_key}'
-        return self._resolver(partial(self.delete, url, params={'deletesubtasks': delete_subtasks}))
-
+        return self._resolver(partial(self.delete, f'{self.base_url}/issue/{issue_key}',
+                                      params={'deletesubtasks': delete_subtasks}))
 
     def update_issue(self, issue_key:str, content: dict) -> requests.Response:
         """
@@ -146,11 +156,9 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from put
         """
-        url = f'{self.base_url}/issue/{issue_key}'
         if 'fields' not in content:
             content = {'fields': content}
-        return self._resolver(partial(self.put, url, data=json.dumps(content)))
-
+        return self._resolver(partial(self.put, f'{self.base_url}/issue/{issue_key}', data=json.dumps(content)))
 
     def account_info(self) -> requests.Response:
         """
@@ -158,8 +166,7 @@ class JiraSession(requests.Session):
 
         return {int} -- accountid or None
         """
-        url = f'{self.base_url}/myself'
-        return self.get(url)
+        return self._resolver(partial(self.get,f'{self.base_url}/myself'))
 
     def assign_issue(self, issue_key: str, accountid: str) -> requests.Response:
         """
@@ -167,8 +174,8 @@ class JiraSession(requests.Session):
 
         issue_key {str} -- newly created issue key
         """
-        url = f'{self.base_url}/issue/{issue_key}/assignee'
-        return self._resolver(partial(self.put, url, data=json.dumps({'accountId': accountid})))
+        return self._resolver(partial(self.put, f'{self.base_url}/issue/{issue_key}/assignee',
+                                      data=json.dumps({'accountId': accountid})))
 
     def get_transitions_from_issue(self, issue_key: str) -> requests.Response:
         """
@@ -178,8 +185,7 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from get to transitions route
         """
-        url = f'{self.base_url}/issue/{issue_key}/transitions'
-        return self._resolver(partial(self.get, url))
+        return self._resolver(partial(self.get, f'{self.base_url}/issue/{issue_key}/transitions'))
 
     def transition_issue(self, issue_key: str, transition_state_id: str) -> requests.Response:
         """
@@ -190,8 +196,8 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from post to transitions route
         """
-        url = f'{self.base_url}/issue/{issue_key}/transitions'
-        return self._resolver(partial(self.post, url, data=json.dumps({'transition': {'id': transition_state_id}})))
+        return self._resolver(partial(self.post, f'{self.base_url}/issue/{issue_key}/transitions',
+                                      data=json.dumps({'transition': {'id': transition_state_id}})))
 
     def add_comment(self, issue_key: str, comment: str) -> requests.Response:
         """
@@ -202,8 +208,8 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from post to comment route
         """
-        url = f'{self.base_url}/issue/{issue_key}/comment'
-        return self._resolver(partial(self.post, url, data=json.dumps({'body': comment})))
+        return self._resolver(partial(self.post, f'{self.base_url}/issue/{issue_key}/comment',
+                                      data=json.dumps({'body': comment})))
 
     def track_issue_time(self, issue_key:str, time_spent: str) -> requests.Response:
         """
@@ -214,13 +220,15 @@ class JiraSession(requests.Session):
 
         return {requests.Response} -- response from post to worklog route
         """
-        url = f'{self.base_url}/issue/{issue_key}/worklog'
-        return self._resolver(partial(self.post, url, data=json.dumps({'timeSpent': time_spent})))
+        return self._resolver(partial(self.post, f'{self.base_url}/issue/{issue_key}/worklog',
+                                      data=json.dumps({'timeSpent': time_spent})))
 
     def get_jira_user(self, username: Union[str, list]) -> requests.Response:
         """
         get user information for jira users by usernames
 
+        DEPRECATED
+
         username {Union[str, list]} -- a username or list of usernames
 
         return {requests.Response} -- the response from the user bulk route
@@ -232,6 +240,17 @@ class JiraSession(requests.Session):
             url += f'username={"&username=".join(username)}'
         return self._resolver(partial(self.get, url))
 
+    def user_search(self, query: str):
+        """
+        search user information using jql
+
+        :param query: {str} -- the jql string to search
+            Ex: emailAddress = username@emaildomain.com
+
+        :return: {requests.Response} -- response from the search
+        """
+        return self._resolver(partial(self.get, f'{self.base_url}/user/search', params={'query':query}))
+
     def assign_to_me(self, issue_key: str) -> requests.Response:
         """
         assign to yourself based on jirauser.userid
